Documentation
¶
Index ¶
Constants ¶
const ( ThemeAuto = "auto" ThemeLight = "light" ThemeDark = "dark" )
Built-in theme names that map to embedded CSS files
Variables ¶
This section is empty.
Functions ¶
func ResolveTheme ¶
ResolveTheme resolves "auto" to the system theme, or returns the theme as-is. When theme is "auto", it detects the system's dark/light preference and uses themeLight or themeDark if they are set, otherwise falls back to "light" or "dark".
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.